@@ -9,7 +9,7 @@ BEGIN {
 use strict;
 use warnings;
 
-our $VERSION = '0.1900';
+our $VERSION = '0.1901';
 
 1;
 
@@ -25,7 +25,7 @@ Task::MusicBundle - A bundle of MIDI and music modules
 
 =head1 VERSION
 
-version 0.1900
+version 0.1901
 
 =head1 SYNOPSIS
 
@@ -49,10 +49,6 @@ what?  B<Music is older than agriculture.>
 
 =head1 CONTENTS
 
-L<Acme::Vuvuzela>
-
-L<App::Music::PlayTab>
-
 L<App::MusicTools>
 
 L<Csound>
@@ -113,8 +109,6 @@ L<Music::Interval::Barycentric>
 
 L<Music::Intervals>
 
-L<Music::LilyPondUtil>
-
 L<Music::NeoRiemannianTonnetz>
 
 L<Music::Note::Frequency>
